==============
konesyntees.py
==============


.. image:: https://img.shields.io/pypi/v/konesyntees.svg
        :target: https://pypi.python.org/pypi/konesyntees

Python client for the voice synthesis service by the Institute of the Estonian Language.


* Free software: MIT license
* Documentation: coming soon.


Features
--------

* TODO
